.. meta::
    :description lang=en:
        Download one or multiple XML sitemaps into a pandas DataFrame with
        Python. You can download URLs from a regular sitemap, or from a sitemap
        index file.

.. automodule:: advertools.sitemaps
   :members:
   :undoc-members:
   :show-inheritance:
